@@ -164,6 +164,8 @@ class ProtobufDescriptorChecker(BaseChecker):
     def _check_init_kwargs(self, node):
         # type: (astroid.Call) -> None
         desc = _get_protobuf_descriptor(node.func)
+        if desc is None:
+            return
         keywords = node.keywords or []
         for kw in keywords:
             arg_name, val_node = kw.arg, kw.value
@@ -231,7 +233,7 @@ class ProtobufDescriptorChecker(BaseChecker):
             vals = []
             for elem in arg.elts:
                 c = _get_inferred_values(elem)
-                if c is None:
+                if not c:
                     continue
                 c = c[0]
                 if not hasattr(c, 'value'):
@@ -244,6 +246,8 @@ class ProtobufDescriptorChecker(BaseChecker):
             arg_name = expr.attrname
         except AttributeError:
             return  # only checking <...>.repeated_field.append()
+        if desc is None:
+            return
         try:
             arg_type = to_pytype(desc.fields_by_name[arg_name])
         except KeyError:
